% GMMEstPar parameters estimation of Gaussian mixture model (GMM) given by sum of two Gaussian PDF
%    [sga1opt,sga2opt,aopt] = GMMEstPar(data) estimates GMM parameters 
%    of given data. Parameters are estimated by simplified equation 
%    system derived by method of moments. The second and fourth central 
%    moments are compared with second and fourth sample central moments.
%
%    jan.svihlik@vscht.cz

function[sga1opt,sga2opt,aopt] = GMMEstPar(data)


sga1opt = prctile(data(:)-mean(data(:)),99.9)/3.0;   % estimation of first GMM standard deviation
M2 = moment(data(:),2);                              % evaluation of second sample central moment
M4 = moment(data(:),4);                              % evaluation of fourth sample central moment

%%%%%%%%%%%%%%%%%%%%%%%%%%
%  MOMENT EQUATIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%

aopt = (-3*M2^2 + M4)/(M4 - 6*M2*sga1opt^2 + 3*sga1opt^4);
while aopt*sga1opt^2>M2 
    %warning('Parameter a was decreased');  
    aopt = aopt-0.05;
end;

sga2opt = sqrt((M2 - aopt*sga1opt^2)/(1 - aopt));
 













