% JefDiv evaluation of Jeffrey divergence, a measure of distribution similarity 
%      [JD] = JefDiv(data,model) evaluates the Jeffrey divergence between two 
%      probality density functions (PDF)
%
%      jan.svihlik@vscht.cz


function[JD] = JefDiv(data,model)

    JDa = data.*log(data./(0.5*(data + model)));
    JDb = model.*log(model./(0.5*(data + model)));

Im = find(model==0); Id = find(data==0);
JDa(Id) = 0; JDb(Im) = 0;                         % cases, where model and data PDF are equal to 0,
                                                  % hence, 0*log0 = 0 and 0*log(...) = 0;
JD = JDa + JDb;
JD = sum(JD);

