% OptHistEval evaluates an optimal histogram of given data
%    [C,X,Wbin] = OptHistEval(band) computes histogram C in X with bin
%    width Wbin estimated in accordance with [1]
%
%    [1] D. W. Scott (1979, Dec.), On optimal and data-based histograms.Biometrika. 66(3), pp. 605-610
%
%    jan.svihlik@vscht.cz


function[C,X,Wbin] = OptHistEval(band)

[M,N] = size(band);
proc_dwn = 0.00;                                              
proc_up = 100 - proc_dwn;
       prc = prctile(band(:)',[proc_dwn proc_up]);    
      Wbin = 2*(iqr(band(:)))*(M*N)^(-1/3);         % optimal bin width (Freedman and Diaconis [1])       

pom1 = fliplr(0:-Wbin:prc(1));                   
pom2 = Wbin:Wbin:prc(2);

         X = [pom1 pom2];                                  
     [C,X] = hist(band(:),X);          