% Demonstration of GMMEstPar usage
% demoGMM models the real and artificial data in the wavelet domain by
% Gaussian mixture model (GMM). 
%
% jan.svihlik@vscht.cz


clear all
close all

k = menu('LOADING OF DATA','REAL','ARTIFICIAL');
switch(k)
    case(1)
img = double(imread('tire.tif','tif'));
    case(2)
img = 10*randn(256,256); 
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  DISCRETE WAVELET TRANSFORM
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load db9; load db10; w = db9;    
input = img;

[Lo_D,Hi_D,Lo_R,Hi_R] = orthfilt(w);                  
[LL,LH,HL,HH] = dwt2(input,Lo_D,Hi_D);                
[LL2,LH2,HL2,HH2] = dwt2(LL,Lo_D,Hi_D);               
[LL3,LH3,HL3,HH3] = dwt2(LL2,Lo_D,Hi_D);              
[LL4,LH4,HL4,HH4] = dwt2(LL3,Lo_D,Hi_D);             
[LL5,LH5,HL5,HH5] = dwt2(LL4,Lo_D,Hi_D);              

band = LH3;
[sga1opt,sga2opt,aopt] = GMMEstPar(band);          % GMM parameters estimation 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  HISTOGRAM OPTIMISATION AND 
%  NORMALIZATION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[C,X,Wbin] = OptHistEval(band);           % histogram optimization

C = C/(Wbin*sum(C(1:end-1)));             % histogram normalization to unit area

pxest = aopt*normpdf(X,0,(sga1opt)) + (1 - aopt)*normpdf(X,0,sga2opt); % estimated model of PDF

warning('off')
JD = JefDiv(C,pxest)           % evaluation of Jeffrey divergence

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  PLOT OF ESTIMATED GMM ALONG WITH
%  NORMALIZED HISTOGRAM
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                  
figure; set(gcf,'position',[360 440 500 300]); set(gca,'fontSize',12,'color',[0.5 0.5 0.5]); 
plot(X,log10(C),'-b','LineWidth',3); hold on
plot(X,log10(pxest),'r','LineWidth',3); 
% axis([-60 60 -5 max(log10(pxest))+0.5 ]); hold off;
xlabel('X','fontSize', 14'); ylabel('Log_1_0[p_X(X)]','fontSize', 14');
legend('Histogram','Model')
warning('on')
